from django.conf.urls import patterns, url

from views import ExternalLinkView

urlpatterns = patterns('',
    url(r'^goto/(?P<external_url>.+)$', ExternalLinkView.as_view(), name='external_link'),
)



import base64
from django.core.urlresolvers import reverse_lazy
from django.template import Library

register = Library()


@register.simple_tag
def external_url(url):
    """Trap external click on external"""
    url = base64.encodestring(url.encode('utf-8')).replace("\n", "")
    return reverse_lazy('external_link', kwargs={'external_url': url})




import base64
from django.views.generic import RedirectView
from external_urls.signals import external_click


class ExternalLinkView(RedirectView):

    permanent = False

    def dispatch(self, request, external_url, *args, **kwargs):
        ip = request.META['REMOTE_ADDR']
        self.url = base64.decodestring(external_url)
        external_click.send_robust(sender=self.__class__, url=self.url, ip=ip)
        return super(ExternalLinkView, self).dispatch(request, *args, **kwargs)
